@@ -1,6 +1,7 @@
 #!/usr/local/bin/perl -w
 use FindBin;
 use Cwd;
+use vars qw($running_under_some_shell);
 
 # We need to be extra careful to make sure envy.pl picks-up the right
 # version of Envy::DB.
@@ -172,6 +173,9 @@ sub HELP {
    MYTOP=\$ENVY_BASE                  # Real path to envy without etc/envy/.
    MYTOP=\$ENVY_LINKBASE              # Path to envy without etc/envy/.
 
+   Envy looks in \$HOME/.envy/ for environment files.  You may use this
+   directory for testing.
+
 3] ENVIRONMENT VARIABLES
 
    \$ENVY_PATH      - Colin separated search path. Envys are typically
